import {EventData, Frame, Http, ListView, NavigatedData, Page} from "@nativescript/core";
import {vm} from "./collectionview-view-model";

let page: Page;
let listview: ListView;

const initialItems = [
  {id: "1", title: "This is the item with number 1 and a very very very long title text, on some devices the title will need more than 2 lines to display"},
  {id: "2", title: "This is the item with number 2"},
  {id: "3", title: "This is the item with number 3 with a long title"},
  {id: "4", title: "This is the item with number 4"},
  {id: "5", title: "This is the item with number 5"},
  {id: "6", title: "This is the item with number 6"},
  {id: "7", title: "This is the item with number 7 and with an even longer title text than the previous items in the list, on some devices the title will need more than 2 lines to display"},
  {id: "8", title: "This is the item with number 8"},
  {id: "9", title: "This is the item with number 9"},
  {id: "10", title: "This is the item with number 10"},
  {id: "11", title: "This is the item with number 11"},
  {id: "12", title: "This is the item with number 12"},
  {id: "13", title: "This is the item with number 13"},
  {id: "14", title: "This is the item with number 14"},
  {id: "15", title: "This is the item with number 15"},
  {id: "16", title: "This is the item with number 16"},
  {id: "17", title: "This is the item with number 17"},
  {id: "18", title: "This is the item with number 18"},
  {id: "19", title: "This is the item with number 19"},
  {id: "20", title: "This is the item with number 20"}
];

export function onPageNavigatingTo(args: NavigatedData) {
  page = args.object as Page;
  page.bindingContext = vm;

  if(!args.isBackNavigation) {
    loadItems();
  }
}


export function onListViewLoaded(args: EventData) {
  listview = args.object as ListView;
  //listview.refresh();
}


export function onItemLongPress() {
  console.log("long press");
}


export function onItemTap() {
  console.log("tap");

  Frame.topmost().navigate("listview-page");
}


function loadItems(): Promise<void> {
  return new Promise((resolve, reject) => {
    vm.set("isLoading", true);

    /*setTimeout(() => {
      vm.get("items").splice(0, vm.get("items").length);
      vm.get("items").push(...initialItems);

      vm.set("isLoading", false);

      resolve();
    }, 2000);*/

    Http.request({
      url: "https://pokeapi.co/api/v2/ability/?limit=10000",
      method: "GET"
    }).then((response) => {
      const json = response.content.toJSON();

      try {
        vm.get("items").splice(0, vm.get("items").length);
        vm.get("items").push(...json.results.map((data) => {
          return {
            title: data.name,
            id: data.url,
            isNew: false
          }
        }));
      } catch (e) {
        console.log(e);
      }

      vm.set("isLoading", false);
      resolve();
    }, (e) => {
      vm.set("isLoading", true);
      reject();
    });
  });
}


export function deleteItem(args) {
  const bindingContext = args.object.bindingContext;

  console.time();
  vm.get("items").splice(vm.get("items").indexOf(bindingContext), 1);
  console.timeEnd();
}
